textgrad.optimizer
==================

.. automodule:: textgrad.optimizer

   
   
   

   
   
   

   
   
   

   
   
   



.. rubric:: Modules

.. autosummary::
   :toctree:
   :recursive:

   textgrad.optimizer.optimizer
   textgrad.optimizer.prompts

